@@ -318,6 +318,18 @@ def test_AugNormalize(ecvl):
     a.Apply(img)
 
 
+@pytest.mark.parametrize("ecvl", [ecvl_core, ecvl_py])
+def test_AugNormalize_separate(ecvl):
+    img = ecvl.Image([5, 4, 3], ecvl.DataType.uint8, "xyc", ecvl.ColorType.BGR)
+    a = ecvl.AugNormalize([20, 19, 21], [5, 5.5, 6])
+    a.Apply(img)
+    # fromtext
+    f = ecvl.AugNormalize if ecvl is ecvl_core else \
+        ecvl.AugNormalize.fromtext
+    a = f('mean=(20,19,21) std=(5,5.5,6)')
+    a.Apply(img)
+
+
 @pytest.mark.parametrize("ecvl", [ecvl_core, ecvl_py])
 def test_AugCenterCrop(ecvl):
     img = ecvl.Image([8, 6, 3], ecvl.DataType.uint8, "xyc", ecvl.ColorType.BGR)
@@ -330,6 +342,48 @@ def test_AugCenterCrop(ecvl):
     a.Apply(img)
 
 
+@pytest.mark.parametrize("ecvl", [ecvl_core, ecvl_py])
+def test_AugToFloat32(ecvl):
+    img = ecvl.Image([8, 6, 3], ecvl.DataType.uint8, "xyc", ecvl.ColorType.BGR)
+    a = ecvl.AugToFloat32()
+    a.Apply(img)
+    img = ecvl.Image([8, 6, 3], ecvl.DataType.uint8, "xyc", ecvl.ColorType.BGR)
+    a = ecvl.AugToFloat32(2.)
+    a.Apply(img)
+    img = ecvl.Image([8, 6, 3], ecvl.DataType.uint8, "xyc", ecvl.ColorType.BGR)
+    a = ecvl.AugToFloat32(2., 3.)
+    a.Apply(img)
+    # fromtext
+    f = ecvl.AugToFloat32 if ecvl is ecvl_core else \
+        ecvl.AugToFloat32.fromtext
+    a = f('divisor=2. divisor_gt=3.')
+    a.Apply(img)
+
+
+@pytest.mark.parametrize("ecvl", [ecvl_core, ecvl_py])
+def test_AugDivBy255(ecvl):
+    img = ecvl.Image([8, 6, 3], ecvl.DataType.uint8, "xyc", ecvl.ColorType.BGR)
+    a = ecvl.AugDivBy255()
+    a.Apply(img)
+    # fromtext
+    f = ecvl.AugDivBy255 if ecvl is ecvl_core else \
+        ecvl.AugDivBy255.fromtext
+    a = f('')
+    a.Apply(img)
+
+
+@pytest.mark.parametrize("ecvl", [ecvl_core, ecvl_py])
+def test_AugScaleTo(ecvl):
+    img = ecvl.Image([8, 6, 3], ecvl.DataType.uint8, "xyc", ecvl.ColorType.BGR)
+    a = ecvl.AugScaleTo(1, 254)
+    a.Apply(img)
+    # fromtext
+    f = ecvl.AugScaleTo if ecvl is ecvl_core else \
+        ecvl.AugScaleTo.fromtext
+    a = f('new_min=1 new_max=255')
+    a.Apply(img)
+
+
 @pytest.mark.parametrize("ecvl", [ecvl_core, ecvl_py])
 def test_AugmentationFactory(ecvl):
     img = ecvl.Image([5, 4, 3], ecvl.DataType.uint8, "xyc", ecvl.ColorType.BGR)
