@@ -330,3 +330,37 @@ def test_shallow_copy_image(ecvl):
     assert (a == 4).all()
     assert x.IsOwner()
     assert not y.IsOwner()
+
+
+@pytest.mark.parametrize("ecvl", [ecvl_core, ecvl_py])
+def test_ConvertTo(ecvl):
+    x = ecvl.Image([2, 4, 3], ecvl.DataType.uint8, "xyc", ecvl.ColorType.RGB)
+    y = _empty_img(ecvl)
+    a = np.array(x, copy=False)
+    a.fill(128)
+    ecvl.ConvertTo(x, y, ecvl.DataType.int8, False)
+    assert y.elemtype_ == ecvl.DataType.int8
+    b = np.array(y, copy=False)
+    assert (b == -128).all()
+    ecvl.ConvertTo(x, y, ecvl.DataType.int8, True)
+    assert y.elemtype_ == ecvl.DataType.int8
+    b = np.array(y, copy=False)
+    assert (b == 127).all()
+
+
+@pytest.mark.parametrize("ecvl", [ecvl_core, ecvl_py])
+def test_ConvertTo_method(ecvl):
+    x = ecvl.Image([2, 4, 3], ecvl.DataType.uint8, "xyc", ecvl.ColorType.RGB)
+    a = np.array(x, copy=False)
+    a.fill(128)
+    x.ConvertTo(ecvl.DataType.int8, False)
+    assert x.elemtype_ == ecvl.DataType.int8
+    a = np.array(x, copy=False)
+    assert (a == -128).all()
+    x = ecvl.Image([2, 4, 3], ecvl.DataType.uint8, "xyc", ecvl.ColorType.RGB)
+    a = np.array(x, copy=False)
+    a.fill(128)
+    x.ConvertTo(ecvl.DataType.int8, True)
+    assert x.elemtype_ == ecvl.DataType.int8
+    a = np.array(x, copy=False)
+    assert (a == 127).all()
